@@ -85,6 +85,7 @@ struct _GladeDesignLayoutPrivate
 
   /* Colors */
   GdkRGBA fg_color;
+  GdkRGBA bg_color;
   GdkRGBA frame_color[2];
   GdkRGBA frame_color_active[2];
 
@@ -924,24 +925,6 @@ on_glade_widget_name_notify (GObject *gobject, GParamSpec *pspec, GladeDesignLay
   gtk_widget_queue_resize (GTK_WIDGET (layout));
 }
 
-static void
-widget_reset_bg_color (GtkWidget *widget)
-{
-  GtkStyleContext *context = gtk_style_context_new ();
-  GtkWidgetPath *path = gtk_widget_path_new ();
-  GdkRGBA bg_color;
-  
-  gtk_widget_path_append_type (path, G_OBJECT_TYPE (widget));
-  gtk_style_context_set_path (context, path);
-  gtk_widget_path_free (path);
-
-  gtk_style_context_get_background_color (context, GTK_STATE_FLAG_NORMAL, &bg_color);
-  gtk_widget_override_background_color (widget, GTK_STATE_FLAG_NORMAL, &bg_color);  
-
-  g_object_unref (context);
-}
-
-
 static void
 glade_design_layout_add (GtkContainer *container, GtkWidget *widget)
 {
@@ -952,11 +935,6 @@ glade_design_layout_add (GtkContainer *container, GtkWidget *widget)
   layout->priv->current_width = 0;
   layout->priv->current_height = 0;
 
-  /*FIXME: Adwaita theme, for some unknown reason, overwrites the window default bg.
-   *  This is a workaround to reset it to the default value.
-   */
-  widget_reset_bg_color (widget);
-  
   gtk_widget_set_parent_window (widget, priv->offscreen_window);
 
   GTK_CONTAINER_CLASS (glade_design_layout_parent_class)->add (container,
@@ -1472,7 +1450,7 @@ glade_design_layout_draw (GtkWidget *widget, cairo_t *cr)
           gint border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
           gboolean selected = FALSE;
           GList *l;
-          
+
           /* draw offscreen widgets */
           gdk_cairo_set_source_window (cr, priv->offscreen_window,
                                        priv->child_offset, priv->child_offset);
@@ -1677,7 +1655,7 @@ glade_design_layout_realize (GtkWidget * widget)
 
   context = gtk_widget_get_style_context (widget);
   gtk_style_context_set_background (context, priv->window);
-  gtk_style_context_set_background (context, priv->offscreen_window);
+  gdk_window_set_background_rgba (priv->offscreen_window, &priv->bg_color);
   gdk_window_show (priv->offscreen_window);
 
   gdk_window_set_cursor (priv->window, NULL);
@@ -1694,7 +1672,7 @@ glade_design_layout_realize (GtkWidget * widget)
   priv->cursors[ACTIVITY_MARGINS_TOP_LEFT] = gdk_cursor_new_for_display (display, GDK_TOP_LEFT_CORNER);
   priv->cursors[ACTIVITY_MARGINS_TOP_RIGHT] = gdk_cursor_new_for_display (display, GDK_TOP_RIGHT_CORNER);
   priv->cursors[ACTIVITY_MARGINS_BOTTOM_LEFT] = gdk_cursor_new_for_display (display, GDK_BOTTOM_LEFT_CORNER);
-  priv->cursors[ACTIVITY_MARGINS_BOTTOM_RIGHT] = gdk_cursor_ref (priv->cursors[ACTIVITY_RESIZE_WIDTH_AND_HEIGHT]);
+  priv->cursors[ACTIVITY_MARGINS_BOTTOM_RIGHT] = g_object_ref (priv->cursors[ACTIVITY_RESIZE_WIDTH_AND_HEIGHT]);
   
   priv->widget_name = pango_layout_new (gtk_widget_get_pango_context (widget));
 }
@@ -1719,7 +1697,7 @@ glade_design_layout_unrealize (GtkWidget * widget)
     {
       if (priv->cursors[i])
         {
-          gdk_cursor_unref (priv->cursors[i]);
+          g_object_unref (priv->cursors[i]);
           priv->cursors[i] = NULL;
         }
     }
@@ -1739,46 +1717,24 @@ static void
 glade_design_layout_style_updated (GtkWidget *widget)
 {
   GladeDesignLayoutPrivate *priv = GLADE_DESIGN_LAYOUT_GET_PRIVATE (widget);
-  GtkStyleContext *context = gtk_style_context_new ();
-  GtkWidgetPath *path = gtk_widget_path_new ();
-  GdkRGBA bg_color;
+  GtkStyleContext *context = gtk_widget_get_style_context (widget);
 
-  g_type_class_ref (GTK_TYPE_TREE_VIEW);
-  gtk_widget_path_append_type (path, GTK_TYPE_WIDGET);
-  gtk_style_context_set_path (context, path);
-  gtk_style_context_add_class (context, GTK_STYLE_CLASS_VIEW);
-  gtk_widget_path_free (path);
+  gtk_style_context_lookup_color (context, "fg_color", &priv->fg_color);
+  gtk_style_context_lookup_color (context, "bg_color", &priv->frame_color[0]);
+  gtk_style_context_lookup_color (context, "selected_bg_color", &priv->frame_color_active[0]);
+  gtk_style_context_lookup_color (context, "selected_fg_color", &priv->frame_color_active[1]);
 
-  gtk_style_context_get_background_color (context,
-                                          GTK_STATE_FLAG_NORMAL,
-                                          &bg_color);
-  gtk_style_context_get_color (context,
-                               GTK_STATE_FLAG_NORMAL,
-                               &priv->fg_color);
-  
-  gtk_style_context_get_background_color (context, GTK_STATE_FLAG_SELECTED,
-                                          &priv->frame_color[0]);
-  gtk_style_context_get_color (context, GTK_STATE_FLAG_SELECTED,
-                               &priv->frame_color[1]);
-  
-  gtk_style_context_get_background_color (context,
-                                          GTK_STATE_FLAG_SELECTED |
-                                          GTK_STATE_FLAG_FOCUSED,
-                                          &priv->frame_color_active[0]);
-  gtk_style_context_get_color (context,
-                               GTK_STATE_FLAG_SELECTED |
-                               GTK_STATE_FLAG_FOCUSED,
-                               &priv->frame_color_active[1]);
-  
-  gtk_widget_override_background_color (widget, GTK_STATE_FLAG_NORMAL, &bg_color);
+  priv->frame_color[1] = priv->fg_color;
+  priv->bg_color = priv->frame_color[0];
 
-  g_object_unref (context);
+  if (priv->offscreen_window)  gdk_window_set_background_rgba (priv->offscreen_window, &priv->bg_color);
 }
 
 static void
 glade_design_layout_init (GladeDesignLayout *layout)
 {
   GladeDesignLayoutPrivate *priv;
+  GtkCssProvider *provider;
   gint i;
   
   layout->priv = priv = GLADE_DESIGN_LAYOUT_GET_PRIVATE (layout);
@@ -1796,6 +1752,16 @@ glade_design_layout_init (GladeDesignLayout *layout)
   priv->south.height = PADDING + OUTLINE_WIDTH;
 
   gtk_widget_set_has_window (GTK_WIDGET (layout), TRUE);
+
+  provider = gtk_css_provider_new ();
+  gtk_css_provider_load_from_data (provider,
+                                   "GladeDesignLayout {\n"
+                                   "  background-color : @base_color;\n"
+                                   "  }", -1, NULL);
+
+  gtk_style_context_add_provider (gtk_widget_get_style_context (GTK_WIDGET (layout)),
+                                  GTK_STYLE_PROVIDER (provider),
+                                  GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 }
 
 static void
@@ -1899,7 +1865,9 @@ glade_design_layout_constructor (GType                  type,
                     "selection-changed",
                     G_CALLBACK (on_project_selection_changed),
                     GLADE_DESIGN_LAYOUT (object));
-                    
+
+  glade_design_layout_style_updated (GTK_WIDGET (object));
+
   return object;
 }
 
