@@ -283,7 +283,7 @@ glade_eprop_accel_populate_view (GladeEditorProperty * eprop,
             {
               info = l->data;
 
-              if (strcmp (info->signal, glade_signal_class_get_name (sclass)))
+              if (g_strcmp0 (info->signal, glade_signal_class_get_name (sclass)))
                 continue;
 
               accel_text = gtk_accelerator_name (info->key, info->modifiers);
@@ -520,7 +520,7 @@ glade_eprop_accel_show_dialog (GtkWidget * dialog_button,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                         GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 
-  vbox = gtk_vbox_new (FALSE, 6);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_widget_show (vbox);
 
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
@@ -593,7 +593,7 @@ glade_eprop_accel_create_input (GladeEditorProperty * eprop)
   GtkWidget *hbox;
   GtkWidget *button;
 
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   eprop_accel->entry = gtk_entry_new ();
   gtk_editable_set_editable (GTK_EDITABLE (eprop_accel->entry), FALSE);
   gtk_widget_show (eprop_accel->entry);
